@@ -11,14 +11,16 @@ class TaxReturns(Resource):
     def create(
         self,
         link: str,
-        year_from: str,
-        year_to: str,
+        year_from: str = None,
+        year_to: str = None,
         *,
         attach_pdf: bool = False,
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
         type_: Optional[TaxReturnType] = None,
+        date_from: str = None,
+        date_to: str = None,
         **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
@@ -30,7 +32,7 @@ class TaxReturns(Resource):
             year_to = year_to or str(date.today().year)
             data.update(year_to=year_to, year_from=year_from)
         else:
-            data.update(date_to=year_to, date_from=year_from)
+            data.update(date_to=date_to, date_from=date_from)
 
         if encryption_key:
             data.update(encryption_key=encryption_key)
